@@ -29,7 +29,11 @@ getData <- function(name='GADM', download=TRUE, path='', ...) {
 	fn <- paste(tempfile(), '.download', sep='')
 	res <- download.file(url=aurl, destfile=fn, method="auto", quiet = FALSE, mode = "wb", cacheOK = TRUE)
 	if (res == 0) {
-		file.rename(fn, filename)
+		if (! file.rename(fn, filename) ) { 
+			# rename failed, perhaps because fn and filename refer to different devices
+			file.copy(fn, filename)
+			file.remove(fn)
+		}
 	} else {
 		stop('could not download the file' )
 	}
